@@ -7,8 +7,12 @@ from random import *
 def main():
     if len(sys.argv) > 1:
         # Usage:
-        #     $ python -m carlo 'd(6)+d(12)'
-        compiled_fns = [compile(arg, f'<argv_function_{i}>', 'eval') for i, arg in enumerate(sys.argv[1:])]
+        #     $ carlo "d(6)+d(12)"
+
+        # Fix issue where Windows users typing single quotes would cause
+        # quoted strings to be passed as argument.
+        args = [arg.strip('\'"') for arg in sys.argv[1:]]
+        compiled_fns = [compile(arg, f'<argv_function_{i}>', 'eval') for i, arg in enumerate(args)]
         sequences_or_fns = [lambda compiled_fn=compiled_fn: eval(compiled_fn) for compiled_fn in compiled_fns]
         labels = sys.argv[1:]
     else:
